@@ -3,7 +3,7 @@
 // Purpose:     Media Transcoder Interface
 // Author:      Alex Thuering
 // Created:     26.04.2008
-// RCS-ID:      $Id: mediatrc.h,v 1.4 2008/11/09 19:56:43 ntalex Exp $
+// RCS-ID:      $Id: mediatrc.h,v 1.6 2010/10/10 16:11:04 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     GPL
 /////////////////////////////////////////////////////////////////////////////
@@ -13,6 +13,15 @@
 
 #include "mediaenc.h"
 #include "wx/dynarray.h"
+#include <vector>
+
+using namespace std;
+
+enum FirstField {
+	ffAUTO = -1,
+	ffBOTTOM = 0,
+	ffTOP = 1
+};
 
 class wxMediaTranscoder {
 public:
@@ -26,6 +35,14 @@ public:
 	/** Sets output file and video/audio/subtitle formats. */
 	virtual bool SetOutputFile(const wxString& fileName, VideoFormat videoFormat, wxArrayInt audioFormats,
 		wxArrayInt subtitleFormats, int videoBitrate = 6000, bool vbr = false, int audioBitrate = 224) = 0;
+	/** Sets pad values */
+	void SetPad(const vector<int>& pad);
+	/** Sets crop values */
+	void SetCrop(const vector<int>& crop);
+	/** Sets interlaced encoding flag */
+	void SetInterlaced(bool value);
+	/** Sets first field flag (Auto, TFF, BFF) */
+	void SetFirstField(FirstField firstField);
 	/** Starts transcoding. */
 	virtual bool Run(bool& canceled) = 0;
 	/** Ends ttanscoding and closes all fiies. */
